==> zio-aws-servicequotas_2.12-5.17.153.1-sources.jar: zio/aws/servicequotas/model/GetAssociationForServiceQuotaTemplateResponse.scala <==
package zio.aws.servicequotas.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetAssociationForServiceQuotaTemplateResponse(
    serviceQuotaTemplateAssociationStatus: Option[
      zio.aws.servicequotas.model.ServiceQuotaTemplateAssociationStatus
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse = {
    import GetAssociationForServiceQuotaTemplateResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse
      .builder()
      .optionallyWith(
        serviceQuotaTemplateAssociationStatus.map(value => value.unwrap)
      )(_.serviceQuotaTemplateAssociationStatus)
      .build()
  }
  def asReadOnly
      : zio.aws.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse.ReadOnly =
    zio.aws.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse
      .wrap(buildAwsValue())
}
object GetAssociationForServiceQuotaTemplateResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse =
      zio.aws.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse(
        serviceQuotaTemplateAssociationStatus.map(value => value)
      )
    def serviceQuotaTemplateAssociationStatus: Option[
      zio.aws.servicequotas.model.ServiceQuotaTemplateAssociationStatus
    ]
    def getServiceQuotaTemplateAssociationStatus: ZIO[
      Any,
      AwsError,
      zio.aws.servicequotas.model.ServiceQuotaTemplateAssociationStatus
    ] = AwsError.unwrapOptionField(
      "serviceQuotaTemplateAssociationStatus",
      serviceQuotaTemplateAssociationStatus
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse
  ) extends zio.aws.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse.ReadOnly {
    override val serviceQuotaTemplateAssociationStatus: Option[
      zio.aws.servicequotas.model.ServiceQuotaTemplateAssociationStatus
    ] = scala
      .Option(impl.serviceQuotaTemplateAssociationStatus())
      .map(value =>
        zio.aws.servicequotas.model.ServiceQuotaTemplateAssociationStatus
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse
  ): zio.aws.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-servicequotas_2.12-5.17.295.19-sources.jar: zio/aws/servicequotas/model/GetAssociationForServiceQuotaTemplateResponse.scala <==
package zio.aws.servicequotas.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetAssociationForServiceQuotaTemplateResponse(
    serviceQuotaTemplateAssociationStatus: Optional[
      zio.aws.servicequotas.model.ServiceQuotaTemplateAssociationStatus
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse = {
    import GetAssociationForServiceQuotaTemplateResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse
      .builder()
      .optionallyWith(
        serviceQuotaTemplateAssociationStatus.map(value => value.unwrap)
      )(_.serviceQuotaTemplateAssociationStatus)
      .build()
  }
  def asReadOnly
      : zio.aws.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse.ReadOnly =
    zio.aws.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse
      .wrap(buildAwsValue())
}
object GetAssociationForServiceQuotaTemplateResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse =
      zio.aws.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse(
        serviceQuotaTemplateAssociationStatus.map(value => value)
      )
    def serviceQuotaTemplateAssociationStatus: Optional[
      zio.aws.servicequotas.model.ServiceQuotaTemplateAssociationStatus
    ]
    def getServiceQuotaTemplateAssociationStatus: ZIO[
      Any,
      AwsError,
      zio.aws.servicequotas.model.ServiceQuotaTemplateAssociationStatus
    ] = AwsError.unwrapOptionField(
      "serviceQuotaTemplateAssociationStatus",
      serviceQuotaTemplateAssociationStatus
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse
  ) extends zio.aws.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse.ReadOnly {
    override val serviceQuotaTemplateAssociationStatus: Optional[
      zio.aws.servicequotas.model.ServiceQuotaTemplateAssociationStatus
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.serviceQuotaTemplateAssociationStatus())
      .map(value =>
        zio.aws.servicequotas.model.ServiceQuotaTemplateAssociationStatus
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse
  ): zio.aws.servicequotas.model.GetAssociationForServiceQuotaTemplateResponse.ReadOnly =
    new Wrapper(impl)
}
